@@ -973,19 +973,102 @@ class MetadataDatabase(
         jsii.create(self.__class__, self, [scope, id, props])
 
 
+@jsii.data_type(
+    jsii_type="cdk8s-metaflow.MetadataDatabaseEnvOptions",
+    jsii_struct_bases=[],
+    name_mapping={
+        "host": "host",
+        "password": "password",
+        "port": "port",
+        "user": "user",
+    },
+)
+class MetadataDatabaseEnvOptions:
+    def __init__(
+        self,
+        *,
+        host: typing.Optional[builtins.str] = None,
+        password: typing.Optional[builtins.str] = None,
+        port: typing.Optional[jsii.Number] = None,
+        user: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''
+        :param host: 
+        :param password: 
+        :param port: 
+        :param user: 
+
+        :stability: experimental
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(MetadataDatabaseEnvOptions.__init__)
+            check_type(argname="argument host", value=host, expected_type=type_hints["host"])
+            check_type(argname="argument password", value=password, expected_type=type_hints["password"])
+            check_type(argname="argument port", value=port, expected_type=type_hints["port"])
+            check_type(argname="argument user", value=user, expected_type=type_hints["user"])
+        self._values: typing.Dict[str, typing.Any] = {}
+        if host is not None:
+            self._values["host"] = host
+        if password is not None:
+            self._values["password"] = password
+        if port is not None:
+            self._values["port"] = port
+        if user is not None:
+            self._values["user"] = user
+
+    @builtins.property
+    def host(self) -> typing.Optional[builtins.str]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("host")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def password(self) -> typing.Optional[builtins.str]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("password")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def port(self) -> typing.Optional[jsii.Number]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("port")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
+    @builtins.property
+    def user(self) -> typing.Optional[builtins.str]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("user")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "MetadataDatabaseEnvOptions(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="cdk8s-metaflow.MetadataDatabaseOptions",
     jsii_struct_bases=[],
     name_mapping={
         "architecture": "architecture",
         "auth": "auth",
-        "host": "host",
         "metrics": "metrics",
-        "password": "password",
-        "port": "port",
         "replication": "replication",
         "resources": "resources",
-        "user": "user",
         "volume_permissions": "volumePermissions",
     },
 )
@@ -995,25 +1078,17 @@ class MetadataDatabaseOptions:
         *,
         architecture: typing.Optional[builtins.str] = None,
         auth: typing.Optional[typing.Union[DatabaseAuthOptions, typing.Dict[str, typing.Any]]] = None,
-        host: typing.Optional[builtins.str] = None,
         metrics: typing.Optional[typing.Union[DatabaseMetricsOptions, typing.Dict[str, typing.Any]]] = None,
-        password: typing.Optional[builtins.str] = None,
-        port: typing.Optional[jsii.Number] = None,
         replication: typing.Optional[typing.Union[DatabaseReplicationOptions, typing.Dict[str, typing.Any]]] = None,
         resources: typing.Optional[typing.Union[DatabaseResourcesOptions, typing.Dict[str, typing.Any]]] = None,
-        user: typing.Optional[builtins.str] = None,
         volume_permissions: typing.Optional[typing.Union[DatabaseVolumePermissionsOptions, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param architecture: 
         :param auth: 
-        :param host: 
         :param metrics: 
-        :param password: 
-        :param port: 
         :param replication: 
         :param resources: 
-        :param user: 
         :param volume_permissions: 
 
         :stability: experimental
@@ -1032,33 +1107,21 @@ class MetadataDatabaseOptions:
             type_hints = typing.get_type_hints(MetadataDatabaseOptions.__init__)
             check_type(argname="argument architecture", value=architecture, expected_type=type_hints["architecture"])
             check_type(argname="argument auth", value=auth, expected_type=type_hints["auth"])
-            check_type(argname="argument host", value=host, expected_type=type_hints["host"])
             check_type(argname="argument metrics", value=metrics, expected_type=type_hints["metrics"])
-            check_type(argname="argument password", value=password, expected_type=type_hints["password"])
-            check_type(argname="argument port", value=port, expected_type=type_hints["port"])
             check_type(argname="argument replication", value=replication, expected_type=type_hints["replication"])
             check_type(argname="argument resources", value=resources, expected_type=type_hints["resources"])
-            check_type(argname="argument user", value=user, expected_type=type_hints["user"])
             check_type(argname="argument volume_permissions", value=volume_permissions, expected_type=type_hints["volume_permissions"])
         self._values: typing.Dict[str, typing.Any] = {}
         if architecture is not None:
             self._values["architecture"] = architecture
         if auth is not None:
             self._values["auth"] = auth
-        if host is not None:
-            self._values["host"] = host
         if metrics is not None:
             self._values["metrics"] = metrics
-        if password is not None:
-            self._values["password"] = password
-        if port is not None:
-            self._values["port"] = port
         if replication is not None:
             self._values["replication"] = replication
         if resources is not None:
             self._values["resources"] = resources
-        if user is not None:
-            self._values["user"] = user
         if volume_permissions is not None:
             self._values["volume_permissions"] = volume_permissions
 
@@ -1078,14 +1141,6 @@ class MetadataDatabaseOptions:
         result = self._values.get("auth")
         return typing.cast(typing.Optional[DatabaseAuthOptions], result)
 
-    @builtins.property
-    def host(self) -> typing.Optional[builtins.str]:
-        '''
-        :stability: experimental
-        '''
-        result = self._values.get("host")
-        return typing.cast(typing.Optional[builtins.str], result)
-
     @builtins.property
     def metrics(self) -> typing.Optional[DatabaseMetricsOptions]:
         '''
@@ -1094,22 +1149,6 @@ class MetadataDatabaseOptions:
         result = self._values.get("metrics")
         return typing.cast(typing.Optional[DatabaseMetricsOptions], result)
 
-    @builtins.property
-    def password(self) -> typing.Optional[builtins.str]:
-        '''
-        :stability: experimental
-        '''
-        result = self._values.get("password")
-        return typing.cast(typing.Optional[builtins.str], result)
-
-    @builtins.property
-    def port(self) -> typing.Optional[jsii.Number]:
-        '''
-        :stability: experimental
-        '''
-        result = self._values.get("port")
-        return typing.cast(typing.Optional[jsii.Number], result)
-
     @builtins.property
     def replication(self) -> typing.Optional[DatabaseReplicationOptions]:
         '''
@@ -1126,14 +1165,6 @@ class MetadataDatabaseOptions:
         result = self._values.get("resources")
         return typing.cast(typing.Optional[DatabaseResourcesOptions], result)
 
-    @builtins.property
-    def user(self) -> typing.Optional[builtins.str]:
-        '''
-        :stability: experimental
-        '''
-        result = self._values.get("user")
-        return typing.cast(typing.Optional[builtins.str], result)
-
     @builtins.property
     def volume_permissions(self) -> typing.Optional[DatabaseVolumePermissionsOptions]:
         '''
@@ -1286,7 +1317,7 @@ class MetaflowServiceOptions:
         image: typing.Optional[typing.Union[ImageOptions, typing.Dict[str, typing.Any]]] = None,
         image_pull_secrets: typing.Optional[typing.Sequence[builtins.str]] = None,
         ingress: typing.Optional[typing.Union[IngressOptions, typing.Dict[str, typing.Any]]] = None,
-        metadatadb: typing.Optional[typing.Union[MetadataDatabaseOptions, typing.Dict[str, typing.Any]]] = None,
+        metadatadb: typing.Optional[typing.Union[MetadataDatabaseEnvOptions, typing.Dict[str, typing.Any]]] = None,
         name_override: typing.Optional[builtins.str] = None,
         node_selector: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         pod_annotations: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
@@ -1332,7 +1363,7 @@ class MetaflowServiceOptions:
         if isinstance(ingress, dict):
             ingress = IngressOptions(**ingress)
         if isinstance(metadatadb, dict):
-            metadatadb = MetadataDatabaseOptions(**metadatadb)
+            metadatadb = MetadataDatabaseEnvOptions(**metadatadb)
         if isinstance(security_context, dict):
             security_context = _SecurityContext_bd8348aa(**security_context)
         if isinstance(service, dict):
@@ -1465,12 +1496,12 @@ class MetaflowServiceOptions:
         return typing.cast(typing.Optional[IngressOptions], result)
 
     @builtins.property
-    def metadatadb(self) -> typing.Optional[MetadataDatabaseOptions]:
+    def metadatadb(self) -> typing.Optional[MetadataDatabaseEnvOptions]:
         '''
         :stability: experimental
         '''
         result = self._values.get("metadatadb")
-        return typing.cast(typing.Optional[MetadataDatabaseOptions], result)
+        return typing.cast(typing.Optional[MetadataDatabaseEnvOptions], result)
 
     @builtins.property
     def name_override(self) -> typing.Optional[builtins.str]:
@@ -1668,7 +1699,6 @@ class MetaflowUI(
     jsii_struct_bases=[],
     name_mapping={
         "env": "env",
-        "metaflow_datastore_sysroot_s3": "metaflowDatastoreSysrootS3",
         "affinity": "affinity",
         "autoscaling": "autoscaling",
         "env_from": "envFrom",
@@ -1677,6 +1707,7 @@ class MetaflowUI(
         "image_pull_secrets": "imagePullSecrets",
         "ingress": "ingress",
         "metadatadb": "metadatadb",
+        "metaflow_datastore_sysroot_s3": "metaflowDatastoreSysrootS3",
         "name_override": "nameOverride",
         "node_selector": "nodeSelector",
         "pod_annotations": "podAnnotations",
@@ -1696,7 +1727,6 @@ class MetaflowUIOptions:
         self,
         *,
         env: typing.Mapping[builtins.str, builtins.str],
-        metaflow_datastore_sysroot_s3: builtins.str,
         affinity: typing.Optional[_Affinity_9d28a7c5] = None,
         autoscaling: typing.Optional[typing.Union[AutoscalingOptions, typing.Dict[str, typing.Any]]] = None,
         env_from: typing.Optional[typing.Sequence[_EnvFromSource_2b00ef0f]] = None,
@@ -1704,7 +1734,8 @@ class MetaflowUIOptions:
         image: typing.Optional[typing.Union[ImageOptions, typing.Dict[str, typing.Any]]] = None,
         image_pull_secrets: typing.Optional[typing.Sequence[builtins.str]] = None,
         ingress: typing.Optional[typing.Union[IngressOptions, typing.Dict[str, typing.Any]]] = None,
-        metadatadb: typing.Optional[typing.Union[MetadataDatabaseOptions, typing.Dict[str, typing.Any]]] = None,
+        metadatadb: typing.Optional[typing.Union[MetadataDatabaseEnvOptions, typing.Dict[str, typing.Any]]] = None,
+        metaflow_datastore_sysroot_s3: typing.Optional[builtins.str] = None,
         name_override: typing.Optional[builtins.str] = None,
         node_selector: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         pod_annotations: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
@@ -1720,7 +1751,6 @@ class MetaflowUIOptions:
     ) -> None:
         '''
         :param env: 
-        :param metaflow_datastore_sysroot_s3: 
         :param affinity: 
         :param autoscaling: 
         :param env_from: 
@@ -1729,6 +1759,7 @@ class MetaflowUIOptions:
         :param image_pull_secrets: 
         :param ingress: 
         :param metadatadb: 
+        :param metaflow_datastore_sysroot_s3: 
         :param name_override: 
         :param node_selector: 
         :param pod_annotations: 
@@ -1753,7 +1784,7 @@ class MetaflowUIOptions:
         if isinstance(ingress, dict):
             ingress = IngressOptions(**ingress)
         if isinstance(metadatadb, dict):
-            metadatadb = MetadataDatabaseOptions(**metadatadb)
+            metadatadb = MetadataDatabaseEnvOptions(**metadatadb)
         if isinstance(security_context, dict):
             security_context = _SecurityContext_bd8348aa(**security_context)
         if isinstance(service, dict):
@@ -1767,7 +1798,6 @@ class MetaflowUIOptions:
         if __debug__:
             type_hints = typing.get_type_hints(MetaflowUIOptions.__init__)
             check_type(argname="argument env", value=env, expected_type=type_hints["env"])
-            check_type(argname="argument metaflow_datastore_sysroot_s3", value=metaflow_datastore_sysroot_s3, expected_type=type_hints["metaflow_datastore_sysroot_s3"])
             check_type(argname="argument affinity", value=affinity, expected_type=type_hints["affinity"])
             check_type(argname="argument autoscaling", value=autoscaling, expected_type=type_hints["autoscaling"])
             check_type(argname="argument env_from", value=env_from, expected_type=type_hints["env_from"])
@@ -1776,6 +1806,7 @@ class MetaflowUIOptions:
             check_type(argname="argument image_pull_secrets", value=image_pull_secrets, expected_type=type_hints["image_pull_secrets"])
             check_type(argname="argument ingress", value=ingress, expected_type=type_hints["ingress"])
             check_type(argname="argument metadatadb", value=metadatadb, expected_type=type_hints["metadatadb"])
+            check_type(argname="argument metaflow_datastore_sysroot_s3", value=metaflow_datastore_sysroot_s3, expected_type=type_hints["metaflow_datastore_sysroot_s3"])
             check_type(argname="argument name_override", value=name_override, expected_type=type_hints["name_override"])
             check_type(argname="argument node_selector", value=node_selector, expected_type=type_hints["node_selector"])
             check_type(argname="argument pod_annotations", value=pod_annotations, expected_type=type_hints["pod_annotations"])
@@ -1790,7 +1821,6 @@ class MetaflowUIOptions:
             check_type(argname="argument ui_image", value=ui_image, expected_type=type_hints["ui_image"])
         self._values: typing.Dict[str, typing.Any] = {
             "env": env,
-            "metaflow_datastore_sysroot_s3": metaflow_datastore_sysroot_s3,
         }
         if affinity is not None:
             self._values["affinity"] = affinity
@@ -1808,6 +1838,8 @@ class MetaflowUIOptions:
             self._values["ingress"] = ingress
         if metadatadb is not None:
             self._values["metadatadb"] = metadatadb
+        if metaflow_datastore_sysroot_s3 is not None:
+            self._values["metaflow_datastore_sysroot_s3"] = metaflow_datastore_sysroot_s3
         if name_override is not None:
             self._values["name_override"] = name_override
         if node_selector is not None:
@@ -1842,15 +1874,6 @@ class MetaflowUIOptions:
         assert result is not None, "Required property 'env' is missing"
         return typing.cast(typing.Mapping[builtins.str, builtins.str], result)
 
-    @builtins.property
-    def metaflow_datastore_sysroot_s3(self) -> builtins.str:
-        '''
-        :stability: experimental
-        '''
-        result = self._values.get("metaflow_datastore_sysroot_s3")
-        assert result is not None, "Required property 'metaflow_datastore_sysroot_s3' is missing"
-        return typing.cast(builtins.str, result)
-
     @builtins.property
     def affinity(self) -> typing.Optional[_Affinity_9d28a7c5]:
         '''
@@ -1908,12 +1931,20 @@ class MetaflowUIOptions:
         return typing.cast(typing.Optional[IngressOptions], result)
 
     @builtins.property
-    def metadatadb(self) -> typing.Optional[MetadataDatabaseOptions]:
+    def metadatadb(self) -> typing.Optional[MetadataDatabaseEnvOptions]:
         '''
         :stability: experimental
         '''
         result = self._values.get("metadatadb")
-        return typing.cast(typing.Optional[MetadataDatabaseOptions], result)
+        return typing.cast(typing.Optional[MetadataDatabaseEnvOptions], result)
+
+    @builtins.property
+    def metaflow_datastore_sysroot_s3(self) -> typing.Optional[builtins.str]:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("metaflow_datastore_sysroot_s3")
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def name_override(self) -> typing.Optional[builtins.str]:
@@ -2271,6 +2302,7 @@ __all__ = [
     "ImagePullPolicy",
     "IngressOptions",
     "MetadataDatabase",
+    "MetadataDatabaseEnvOptions",
     "MetadataDatabaseOptions",
     "MetadataDatabaseProps",
     "MetaflowService",
